@@ -162,7 +162,11 @@ class FremantleRotation(object):
             # Ignore repeated requests
             return
 
-        flags = hildon.PORTRAIT_MODE_SUPPORT
+        flags = 0
+
+        if orientation != self._LANDSCAPE:
+            flags |= hildon.PORTRAIT_MODE_SUPPORT
+
         if orientation == self._PORTRAIT:
             flags |= hildon.PORTRAIT_MODE_REQUEST
 
@@ -186,4 +190,4 @@ class FremantleRotation(object):
             else:
                 # Ignore orientation changes for non-automatic modes, but save
                 # the current orientation for "automatic" mode later on
-                self._last_dbus_orientation = orientation
\ No newline at end of file
+                self._last_dbus_orientation = orientation
